@@ -91,7 +91,7 @@ pub unsafe fn take_primitive_unchecked<T: NativeType>(
             }
         });
     };
-    let arr = PrimitiveArray::from_data(T::PRIMITIVE.into(), values.into(), Some(validity.into()));
+    let arr = PrimitiveArray::new(T::PRIMITIVE.into(), values.into(), Some(validity.into()));
 
     Box::new(arr)
 }
@@ -114,11 +114,7 @@ pub unsafe fn take_no_null_primitive_unchecked<T: NativeType>(
 
     let values: Buffer<_> = Vec::from_trusted_len_iter(iter).into();
     let validity = indices.validity().cloned();
-    Box::new(PrimitiveArray::from_data(
-        T::PRIMITIVE.into(),
-        values,
-        validity,
-    ))
+    Box::new(PrimitiveArray::new(T::PRIMITIVE.into(), values, validity))
 }
 
 /// Take kernel for single chunk without nulls and an iterator as index.
@@ -140,7 +136,7 @@ pub unsafe fn take_no_null_primitive_iter_unchecked<T: NativeType, I: TrustedLen
     });
 
     let values: Buffer<_> = Vec::from_trusted_len_iter(iter).into();
-    Box::new(PrimitiveArray::from_data(T::PRIMITIVE.into(), values, None))
+    Box::new(PrimitiveArray::new(T::PRIMITIVE.into(), values, None))
 }
 
 /// Take kernel for a single chunk with null values and an iterator as index.
@@ -245,11 +241,7 @@ pub unsafe fn take_no_null_bool_iter_unchecked<I: IntoIterator<Item = usize>>(
         values.get_bit_unchecked(idx)
     });
     let mutable = MutableBitmap::from_trusted_len_iter_unchecked(iter);
-    Box::new(BooleanArray::from_data(
-        DataType::Boolean,
-        mutable.into(),
-        None,
-    ))
+    Box::new(BooleanArray::new(DataType::Boolean, mutable.into(), None))
 }
 
 /// Take kernel for single chunk and an iterator as index.
