@@ -2,6 +2,7 @@ use std::hash::{Hash, Hasher};
 
 use arrow::types::NativeType;
 use num::traits::NumCast;
+use polars_core::frame::row::AnyValueBuffer;
 use polars_core::prelude::*;
 use polars_time::prelude::utf8::infer::{infer_pattern_single, DatetimeInfer};
 use polars_time::prelude::utf8::Pattern;
@@ -17,102 +18,19 @@ impl<'a> Hash for BufferKey<'a> {
     }
 }
 
-pub(crate) fn init_buffers(
-    schema: &Schema,
-    capacity: usize,
-) -> PolarsResult<PlIndexMap<BufferKey, Buffer>> {
-    schema
-        .iter()
-        .map(|(name, dtype)| {
-            let builder = match dtype {
-                &DataType::Boolean => Buffer::Boolean(BooleanChunkedBuilder::new(name, capacity)),
-                &DataType::Int32 => Buffer::Int32(PrimitiveChunkedBuilder::new(name, capacity)),
-                &DataType::Int64 => Buffer::Int64(PrimitiveChunkedBuilder::new(name, capacity)),
-                &DataType::UInt32 => Buffer::UInt32(PrimitiveChunkedBuilder::new(name, capacity)),
-                &DataType::UInt64 => Buffer::UInt64(PrimitiveChunkedBuilder::new(name, capacity)),
-                &DataType::Float32 => Buffer::Float32(PrimitiveChunkedBuilder::new(name, capacity)),
-                &DataType::Float64 => Buffer::Float64(PrimitiveChunkedBuilder::new(name, capacity)),
-                &DataType::Utf8 => {
-                    Buffer::Utf8(Utf8ChunkedBuilder::new(name, capacity, capacity * 25))
-                }
-                #[cfg(feature = "dtype-datetime")]
-                &DataType::Datetime(_, _) => {
-                    Buffer::Datetime(PrimitiveChunkedBuilder::new(name, capacity))
-                }
-                #[cfg(feature = "dtype-date")]
-                &DataType::Date => Buffer::Date(PrimitiveChunkedBuilder::new(name, capacity)),
-                _ => Buffer::All((Vec::with_capacity(capacity), name)),
-            };
-            let key = KnownKey::from(name);
+pub(crate) struct Buffer<'a>(&'a str, AnyValueBuffer<'a>);
 
-            Ok((BufferKey(key), builder))
-        })
-        .collect()
-}
-
-#[allow(clippy::large_enum_variant)]
-pub(crate) enum Buffer<'a> {
-    Boolean(BooleanChunkedBuilder),
-    Int32(PrimitiveChunkedBuilder<Int32Type>),
-    Int64(PrimitiveChunkedBuilder<Int64Type>),
-    UInt32(PrimitiveChunkedBuilder<UInt32Type>),
-    UInt64(PrimitiveChunkedBuilder<UInt64Type>),
-    Float32(PrimitiveChunkedBuilder<Float32Type>),
-    Float64(PrimitiveChunkedBuilder<Float64Type>),
-    Utf8(Utf8ChunkedBuilder),
-    #[cfg(feature = "dtype-datetime")]
-    Datetime(PrimitiveChunkedBuilder<Int64Type>),
-    #[cfg(feature = "dtype-date")]
-    Date(PrimitiveChunkedBuilder<Int32Type>),
-    All((Vec<AnyValue<'a>>, &'a str)),
-}
-
-impl<'a> Buffer<'a> {
-    pub(crate) fn into_series(self) -> PolarsResult<Series> {
-        let s = match self {
-            Buffer::Boolean(v) => v.finish().into_series(),
-            Buffer::Int32(v) => v.finish().into_series(),
-            Buffer::Int64(v) => v.finish().into_series(),
-            Buffer::UInt32(v) => v.finish().into_series(),
-            Buffer::UInt64(v) => v.finish().into_series(),
-            Buffer::Float32(v) => v.finish().into_series(),
-            Buffer::Float64(v) => v.finish().into_series(),
-            #[cfg(feature = "dtype-datetime")]
-            Buffer::Datetime(v) => v
-                .finish()
-                .into_series()
-                .cast(&DataType::Datetime(TimeUnit::Microseconds, None))
-                .unwrap(),
-            #[cfg(feature = "dtype-date")]
-            Buffer::Date(v) => v.finish().into_series().cast(&DataType::Date).unwrap(),
-            Buffer::Utf8(v) => v.finish().into_series(),
-            Buffer::All((vals, name)) => Series::new(name, vals),
-        };
-        Ok(s)
-    }
-
-    pub(crate) fn add_null(&mut self) {
-        match self {
-            Buffer::Boolean(v) => v.append_null(),
-            Buffer::Int32(v) => v.append_null(),
-            Buffer::Int64(v) => v.append_null(),
-            Buffer::UInt32(v) => v.append_null(),
-            Buffer::UInt64(v) => v.append_null(),
-            Buffer::Float32(v) => v.append_null(),
-            Buffer::Float64(v) => v.append_null(),
-            Buffer::Utf8(v) => v.append_null(),
-            #[cfg(feature = "dtype-datetime")]
-            Buffer::Datetime(v) => v.append_null(),
-            #[cfg(feature = "dtype-date")]
-            Buffer::Date(v) => v.append_null(),
-            Buffer::All((v, _)) => v.push(AnyValue::Null),
-        };
+impl Buffer<'_> {
+    pub fn into_series(self) -> Series {
+        let mut s = self.1.into_series();
+        s.rename(self.0);
+        s
     }
 
     #[inline]
     pub(crate) fn add(&mut self, value: &Value) -> PolarsResult<()> {
-        use Buffer::*;
-        match self {
+        use AnyValueBuffer::*;
+        match &mut self.1 {
             Boolean(buf) => {
                 match value {
                     Value::Static(StaticNode::Bool(b)) => buf.append_value(*b),
@@ -177,7 +95,7 @@ impl<'a> Buffer<'a> {
                 Ok(())
             }
             #[cfg(feature = "dtype-datetime")]
-            Datetime(buf) => {
+            Datetime(buf, _, _) => {
                 let v = deserialize_datetime::<Int64Type>(value);
                 buf.append_option(v);
                 Ok(())
@@ -188,13 +106,30 @@ impl<'a> Buffer<'a> {
                 buf.append_option(v);
                 Ok(())
             }
-            All((buf, _)) => {
+            All(_, buf) => {
                 let av = deserialize_all(value);
                 buf.push(av);
                 Ok(())
             }
+            _ => panic!("unexpected dtype when deserializing ndjson"),
         }
     }
+    pub fn add_null(&mut self) {
+        self.1.add(AnyValue::Null).expect("should not fail");
+    }
+}
+pub(crate) fn init_buffers(
+    schema: &Schema,
+    capacity: usize,
+) -> PolarsResult<PlIndexMap<BufferKey, Buffer>> {
+    schema
+        .iter()
+        .map(|(name, dtype)| {
+            let av_buf = (dtype, capacity).into();
+            let key = KnownKey::from(name);
+            Ok((BufferKey(key), Buffer(name, av_buf)))
+        })
+        .collect()
 }
 
 fn deserialize_number<T: NativeType + NumCast>(value: &Value) -> Option<T> {
