@@ -70,6 +70,7 @@ pub struct GenericGroupbySink {
     // this vec will have two functions. We will use these functions
     // to populate the buffer where the hashmap points to
     agg_fns: Vec<AggregateFunction>,
+    input_schema: SchemaRef,
     output_schema: SchemaRef,
     // amortize allocations
     aggregation_series: Vec<Series>,
@@ -79,10 +80,11 @@ pub struct GenericGroupbySink {
 }
 
 impl GenericGroupbySink {
-    pub fn new(
+    pub(crate) fn new(
         key_columns: Arc<Vec<Arc<dyn PhysicalPipedExpr>>>,
         aggregation_columns: Arc<Vec<Arc<dyn PhysicalPipedExpr>>>,
         agg_fns: Vec<AggregateFunction>,
+        input_schema: SchemaRef,
         output_schema: SchemaRef,
         slice: Option<(i64, usize)>,
     ) -> Self {
@@ -106,6 +108,7 @@ impl GenericGroupbySink {
             aggregation_columns,
             hb,
             agg_fns,
+            input_schema,
             output_schema,
             aggregation_series: vec![],
             keys_series: vec![],
@@ -144,7 +147,7 @@ impl GenericGroupbySink {
                             .output_schema
                             .iter_dtypes()
                             .take(n_keys)
-                            .map(|dtype| AnyValueBuffer::new(dtype, agg_map.len()))
+                            .map(|dtype| AnyValueBuffer::new(&dtype.to_physical(), agg_map.len()))
                             .collect::<Vec<_>>();
                         let dtypes = agg_fns
                             .iter()
@@ -203,12 +206,12 @@ impl Sink for GenericGroupbySink {
 
         // todo! amortize allocation
         for phys_e in self.aggregation_columns.iter() {
-            let s = phys_e.evaluate(&chunk, context.execution_state.as_ref())?;
+            let s = phys_e.evaluate(&chunk, context.execution_state.as_any())?;
             let s = s.to_physical_repr();
             self.aggregation_series.push(s.rechunk());
         }
         for phys_e in self.key_columns.iter() {
-            let s = phys_e.evaluate(&chunk, context.execution_state.as_ref())?;
+            let s = phys_e.evaluate(&chunk, context.execution_state.as_any())?;
             let s = s.to_physical_repr();
             self.keys_series.push(s.rechunk());
         }
@@ -248,15 +251,17 @@ impl Sink for GenericGroupbySink {
             let current_key_values = unsafe { self.keys.get_unchecked_release_mut(partition) };
 
             let entry = current_partition.raw_entry_mut().from_hash(h, |key| {
-                let idx = key.idx as usize;
-                if self.keys_series.len() > 1 {
-                    current_tuple.iter().enumerate().all(|(i, key)| unsafe {
-                        current_key_values.get_unchecked_release(i + idx) == key
-                    })
-                } else {
-                    unsafe {
-                        current_key_values.get_unchecked_release(idx)
-                            == current_tuple.get_unchecked_release(0)
+                key.hash == h && {
+                    let idx = key.idx as usize;
+                    if self.keys_series.len() > 1 {
+                        current_tuple.iter().enumerate().all(|(i, key)| unsafe {
+                            current_key_values.get_unchecked_release(i + idx) == key
+                        })
+                    } else {
+                        unsafe {
+                            current_key_values.get_unchecked_release(idx)
+                                == current_tuple.get_unchecked_release(0)
+                        }
                     }
                 }
             });
@@ -400,6 +405,7 @@ impl Sink for GenericGroupbySink {
             self.key_columns.clone(),
             self.aggregation_columns.clone(),
             self.agg_fns.iter().map(|func| func.split2()).collect(),
+            self.input_schema.clone(),
             self.output_schema.clone(),
             self.slice,
         );
