@@ -1,5 +1,7 @@
 #[cfg(feature = "arg_where")]
 mod arg_where;
+#[cfg(feature = "dtype-binary")]
+mod binary;
 #[cfg(feature = "round_series")]
 mod clip;
 #[cfg(feature = "temporal")]
@@ -38,6 +40,8 @@ use polars_core::prelude::*;
 #[cfg(feature = "serde")]
 use serde::{Deserialize, Serialize};
 
+#[cfg(feature = "dtype-binary")]
+pub(crate) use self::binary::BinaryFunction;
 #[cfg(feature = "temporal")]
 pub(super) use self::datetime::TemporalFunction;
 pub(super) use self::nan::NanFunction;
@@ -64,6 +68,8 @@ pub enum FunctionExpr {
     SearchSorted,
     #[cfg(feature = "strings")]
     StringExpr(StringFunction),
+    #[cfg(feature = "dtype-binary")]
+    BinaryExpr(BinaryFunction),
     #[cfg(feature = "temporal")]
     TemporalExpr(TemporalFunction),
     #[cfg(feature = "date_offset")]
@@ -130,6 +136,8 @@ impl Display for FunctionExpr {
             SearchSorted => "search_sorted",
             #[cfg(feature = "strings")]
             StringExpr(s) => return write!(f, "{s}"),
+            #[cfg(feature = "dtype-binary")]
+            BinaryExpr(b) => return write!(f, "{b}"),
             #[cfg(feature = "temporal")]
             TemporalExpr(fun) => return write!(f, "{fun}"),
             #[cfg(feature = "date_offset")]
@@ -277,6 +285,8 @@ impl From<FunctionExpr> for SpecialEq<Arc<dyn SeriesUdf>> {
             }
             #[cfg(feature = "strings")]
             StringExpr(s) => s.into(),
+            #[cfg(feature = "dtype-binary")]
+            BinaryExpr(s) => s.into(),
             #[cfg(feature = "temporal")]
             TemporalExpr(func) => func.into(),
 
@@ -396,9 +406,27 @@ impl From<StringFunction> for SpecialEq<Arc<dyn SeriesUdf>> {
             Replace { all, literal } => map_as_slice!(strings::replace, literal, all),
             Uppercase => map!(strings::uppercase),
             Lowercase => map!(strings::lowercase),
-            Strip(matches) => map!(strings::strip, matches),
-            LStrip(matches) => map!(strings::lstrip, matches),
-            RStrip(matches) => map!(strings::rstrip, matches),
+            Strip(matches) => map!(strings::strip, matches.as_deref()),
+            LStrip(matches) => map!(strings::lstrip, matches.as_deref()),
+            RStrip(matches) => map!(strings::rstrip, matches.as_deref()),
+        }
+    }
+}
+
+#[cfg(feature = "dtype-binary")]
+impl From<BinaryFunction> for SpecialEq<Arc<dyn SeriesUdf>> {
+    fn from(func: BinaryFunction) -> Self {
+        use BinaryFunction::*;
+        match func {
+            Contains { pat, literal } => {
+                map!(binary::contains, &pat, literal)
+            }
+            EndsWith(sub) => {
+                map!(binary::ends_with, &sub)
+            }
+            StartsWith(sub) => {
+                map!(binary::starts_with, &sub)
+            }
         }
     }
 }
