@@ -11,13 +11,13 @@ fn add_benchmark(c: &mut Criterion) {
     (10..=20).step_by(2).for_each(|log2_size| {
         let size = 2usize.pow(log2_size);
 
-        let ca = Int32Chunked::init_rand(size, 0.0, 10);
+        let ca = Int32Chunked::init_rand(size, 0.0, Some(10));
 
         c.bench_function(&format!("sort 2^{} i32", log2_size), |b| {
             b.iter(|| bench_sort(&ca))
         });
 
-        let ca = Int32Chunked::init_rand(size, 0.1, 10);
+        let ca = Int32Chunked::init_rand(size, 0.1, Some(10));
         c.bench_function(&format!("sort null 2^{} i32", log2_size), |b| {
             b.iter(|| bench_sort(&ca))
         });
