@@ -151,3 +151,22 @@ fn test_projection_5086() -> PolarsResult<()> {
 
     Ok(())
 }
+
+#[test]
+fn test_unnest_pushdown() -> PolarsResult<()> {
+    let df = df![
+        "collection" => Series::full_null("", 1, &DataType::Int32),
+        "users" => Series::full_null("", 1, &DataType::List(Box::new(DataType::Struct(vec![Field::new("email", DataType::Utf8)])))),
+    ]?;
+
+    let out = df
+        .lazy()
+        .explode(["users"])
+        .unnest(["users"])
+        .select([col("email")])
+        .collect()?;
+
+    assert_eq!(out.get_column_names(), &["email"]);
+
+    Ok(())
+}
