@@ -298,7 +298,6 @@ class ListNameSpace:
         │ struct[3]  │
         ╞════════════╡
         │ {1,2,3}    │
-        ├╌╌╌╌╌╌╌╌╌╌╌╌┤
         │ {1,2,null} │
         └────────────┘
         >>> df.select(
@@ -312,6 +311,18 @@ class ListNameSpace:
         {'col_name_0': 1, 'col_name_1': 2, 'col_name_2': None}]
 
         """
+        # We set the upper bound to 0.
+        # No need to create the proper schema in eager mode.
+        s = pli.wrap_s(self)
+        return (
+            s.to_frame()
+            .select(
+                pli.col(s.name).arr.to_struct(
+                    n_field_strategy, name_generator, upper_bound=0
+                )
+            )
+            .to_series()
+        )
 
     def eval(self, expr: pli.Expr, parallel: bool = False) -> pli.Series:
         """
@@ -342,9 +353,7 @@ class ListNameSpace:
         │ i64 ┆ i64 ┆ list[f32]  │
         ╞═════╪═════╪════════════╡
         │ 1   ┆ 4   ┆ [1.0, 2.0] │
-        ├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌┤
         │ 8   ┆ 5   ┆ [2.0, 1.0] │
-        ├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌┤
         │ 3   ┆ 2   ┆ [2.0, 1.0] │
         └─────┴─────┴────────────┘
 
