@@ -268,3 +268,40 @@ def test_categorical_list_concat_4762() -> None:
     q = df.lazy().select([pl.concat_list([pl.col("x").cast(pl.Categorical)] * 2)])
     with pl.StringCache():
         assert q.collect().to_dict(False) == expected
+
+
+def test_categorical_max_null_5437() -> None:
+    assert (
+        pl.DataFrame({"strings": ["c", "b", "a", "c"], "values": [0, 1, 2, 3]})
+        .with_column(pl.col("strings").cast(pl.Categorical).alias("cats"))
+        .select(pl.all().max())
+    ).to_dict(False) == {"strings": ["c"], "values": [3], "cats": [None]}
+
+
+def test_categorical_in_struct_nulls() -> None:
+    s = pl.Series(
+        "job", ["doctor", "waiter", None, None, None, "doctor"], pl.Categorical
+    )
+    df = pl.DataFrame([s])
+    s = (df.select(pl.col("job").value_counts(sort=True)))["job"]
+
+    assert s[0] == {"job": None, "counts": 3}
+    assert s[1] == {"job": "doctor", "counts": 2}
+    assert s[2] == {"job": "waiter", "counts": 1}
+
+
+def test_sort_categoricals_6014() -> None:
+    with pl.StringCache():
+        # create basic categorical
+        df1 = pl.DataFrame({"key": ["bbb", "aaa", "ccc"]}).with_column(
+            pl.col("key").cast(pl.Categorical)
+        )
+        # create lexically-ordered categorical
+        df2 = pl.DataFrame({"key": ["bbb", "aaa", "ccc"]}).with_column(
+            pl.col("key").cast(pl.Categorical).cat.set_ordering("lexical")
+        )
+
+    out = df1.sort("key")
+    assert out.to_dict(False) == {"key": ["bbb", "aaa", "ccc"]}
+    out = df2.sort("key")
+    assert out.to_dict(False) == {"key": ["aaa", "bbb", "ccc"]}
