@@ -89,7 +89,8 @@ def test_init_dict() -> None:
     assert df.schema == {"c": pl.Int8, "d": pl.Int16}
 
     dfe = df.cleared()
-    assert (df.schema == dfe.schema) and (len(dfe) == 0)
+    assert df.schema == dfe.schema
+    assert len(dfe) == 0
 
 
 def test_init_ndarray(monkeypatch: Any) -> None:
@@ -172,7 +173,9 @@ def test_init_ndarray(monkeypatch: Any) -> None:
         _ = pl.DataFrame(np.array([[1, 2], [3, 4]]), columns=["a"])
 
     # NumPy not available
-    monkeypatch.setattr(pl.internals.dataframe.frame, "_NUMPY_TYPE", lambda x: False)
+    monkeypatch.setattr(
+        pl.internals.dataframe.frame, "_check_for_numpy", lambda x: False
+    )
     with pytest.raises(ValueError):
         pl.DataFrame(np.array([1, 2, 3]), columns=["a"])
 
@@ -309,8 +312,7 @@ def test_init_1d_sequence() -> None:
     assert df.rows() == [(None,), (1,), (0,)]
 
     # String sequence
-    with pytest.raises(ValueError):
-        pl.DataFrame("abc")
+    assert pl.DataFrame("abc", columns=["s"]).to_dict(False) == {"s": ["a", "b", "c"]}
 
 
 def test_init_pandas(monkeypatch: Any) -> None:
@@ -357,7 +359,9 @@ def test_init_pandas(monkeypatch: Any) -> None:
     assert df.rows() == [(datetime(2022, 10, 31, 10, 30, 45, 123456),)]
 
     # pandas is not available
-    monkeypatch.setattr(pl.internals.dataframe.frame, "_PANDAS_TYPE", lambda x: False)
+    monkeypatch.setattr(
+        pl.internals.dataframe.frame, "_check_for_pandas", lambda x: False
+    )
     with pytest.raises(ValueError):
         pl.DataFrame(pandas_df)
 
@@ -435,7 +439,8 @@ def test_init_only_columns() -> None:
 
         dfe = df.cleared()
         assert len(dfe) == 0
-        assert (df.schema == dfe.schema) and (dfe.shape == df.shape)
+        assert df.schema == dfe.schema
+        assert dfe.shape == df.shape
 
 
 def test_from_dicts_list_without_dtype() -> None:
