@@ -704,3 +704,29 @@ def test_struct_any_value_get_after_append() -> None:
     a = a.append(b)
     assert a[0] == {"a": 1, "b": 2}
     assert a[1] == {"a": 2, "b": 3}
+
+
+def test_struct_categorical_5843() -> None:
+    df = pl.DataFrame({"foo": ["a", "b", "c", "a"]}).with_column(
+        pl.col("foo").cast(pl.Categorical)
+    )
+    result = df.select(pl.col("foo").value_counts(sort=True))
+    assert result.to_dict(False) == {
+        "foo": [
+            {"foo": "a", "counts": 2},
+            {"foo": "b", "counts": 1},
+            {"foo": "c", "counts": 1},
+        ]
+    }
+
+
+def test_struct_empty() -> None:
+    # List<struct>
+    df = pl.DataFrame({"a": [[{}]]})
+    assert df.to_dict(False) == {"a": [[{"": None}]]}
+    # Struct one not empty
+    df = pl.DataFrame({"a": [[{}, {"a": 10}]]})
+    assert df.to_dict(False) == {"a": [[{"a": None}, {"a": 10}]]}
+    # Empty struct
+    df = pl.DataFrame({"a": [{}]})
+    assert df.to_dict(False) == {"a": [{"": None}]}
